@@ -28,14 +28,14 @@ our %ALLOW_RX = (
 our %ALLOW_VALUE = (
 );
 
-# Used by _value_is_allowed
+# Used by _initialize
 our %DEFAULT_VALUE = (
     'high_priority_login' => 0,
     'timeout' => 180,
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.2 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.3 $' =~ /\$Revision:\s+([^\s]+)/;
 
 1;
 
@@ -180,7 +180,7 @@ Passed to L<set_execution_priority()>. Defaults to B<HH::Unispool::Config::ExecP
 
 =item new_from_tokenizer(TOKENIZER)
 
-This method is an implementation from package C<'HH::Unispool::Config::Entry::RemoteSystem'>. Constructs a new C<HH::Unispool::Config::Entry> object using tokens. C<TOKENIZER> is an C<HH::Unispool::Config::File::Tokenizer> reference. On error an exception C<Error::Simple> is thrown.
+This method is an implementation from package C<HH::Unispool::Config::Entry::RemoteSystem>. Constructs a new C<HH::Unispool::Config::Entry> object using tokens. C<TOKENIZER> is an C<HH::Unispool::Config::File::Tokenizer> reference. On error an exception C<Error::Simple> is thrown.
 
 =back
 
@@ -190,11 +190,55 @@ This method is an implementation from package C<'HH::Unispool::Config::Entry::Re
 
 =item diff(TO [, DIFF_NUMBER])
 
-This method is an implementation from package C<'HH::Unispool::Config::Entry::RemoteSystem'>. Finds differences between two objects. In C<diff> terms, the object is the B<from> object and the specified C<TO> parameter the B<to> object. C<TO> is a reference to an identical object class. Returns an empty string if no difference found and a difference descritpion string otherwise. On error an exception C<Error::Simple> is thrown. Paremeter C<DIFF_NUMBER> if specified, overrules the value of C<get_diff_number>.
+This method is an implementation from package C<HH::Unispool::Config::Entry::RemoteSystem>. Finds differences between two objects. In C<diff> terms, the object is the B<from> object and the specified C<TO> parameter the B<to> object. C<TO> is a reference to an identical object class. Returns an empty string if no difference found and a difference descritpion string otherwise. On error an exception C<Error::Simple> is thrown. Paremeter C<DIFF_NUMBER> if specified, overrules the value of C<get_diff_number>.
 
-=item write(FILE_HANDLE)
+=item get_acct()
 
-This method is an implementation from package C<'HH::Unispool::Config::Entry::RemoteSystem'>. Writes the entry to the specified file handle. C<FILE_HANDLE> is an C<IO::Handle> reference. On error an exception C<Error::Simple> is thrown.
+Returns the remote login account (is not available on development system used).
+
+=item get_apass()
+
+Returns the account password (is not available on development system used).
+
+=item get_description()
+
+This method is inherited from package C<HH::Unispool::Config::Entry::RemoteSystem>. Returns the description for the remote system.
+
+=item get_execution_priority()
+
+This method is inherited from package C<HH::Unispool::Config::Entry::RemoteSystem>. Returns the execution priority of the driver process on MPE hosts.
+
+=item get_name()
+
+This method is inherited from package C<HH::Unispool::Config::Entry>. Returns the entry name.
+
+=item get_number()
+
+This method is inherited from package C<HH::Unispool::Config::Entry::Numbered>. Returns the entry number.
+
+=item get_remote_node_name()
+
+Returns the name of the system as it can be resolved by the network software.
+
+=item get_timeout()
+
+Returns the delay before closing the link after transfering the last request (in seconds) (is not available on development system used).
+
+=item get_upass()
+
+Returns the user paccword (is not available on development system used).
+
+=item is_diff_number()
+
+This method is inherited from package C<HH::Unispool::Config::Entry::Numbered>. Returns whether L<diff()> should consider the C<number> attribtutes or not.
+
+=item is_high_priority_login()
+
+Returns whether the login must be high priotity (is not available on development system used) or not.
+
+=item is_initially_open()
+
+Returns whether the communication link should be opened at the moment UNISPOOL is started or not.
 
 =item set_acct(VALUE)
 
@@ -212,10 +256,6 @@ Set the remote login account (is not available on development system used). C<VA
 
 =back
 
-=item get_acct()
-
-Returns the remote login account (is not available on development system used).
-
 =item set_apass(VALUE)
 
 Set the account password (is not available on development system used). C<VALUE> is the value. On error an exception C<Error::Simple> is thrown.
@@ -232,25 +272,81 @@ Set the account password (is not available on development system used). C<VALUE>
 
 =back
 
-=item get_apass()
+=item set_description(VALUE)
 
-Returns the account password (is not available on development system used).
+This method is inherited from package C<HH::Unispool::Config::Entry::RemoteSystem>. Set the description for the remote system. C<VALUE> is the value. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item VALUE must match regular expression:
+
+=over
+
+=item ^.*$
+
+=back
+
+=back
+
+=item set_diff_number(VALUE)
+
+This method is inherited from package C<HH::Unispool::Config::Entry::Numbered>. State that L<diff()> should consider the C<number> attribtutes. C<VALUE> is the value. Default value at initialization is C<0>. On error an exception C<Error::Simple> is thrown.
+
+=item set_execution_priority(VALUE)
+
+This method is inherited from package C<HH::Unispool::Config::Entry::RemoteSystem>. Set the execution priority of the driver process on MPE hosts. C<VALUE> is the value. Default value at initialization is C<HH::Unispool::Config::ExecPri->new( { execution_priority => '' } )>. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item VALUE must be a (sub)class of:
+
+=over
+
+=item HH::Unispool::Config::ExecPri
+
+=back
+
+=back
 
 =item set_high_priority_login(VALUE)
 
 State that the login must be high priotity (is not available on development system used). C<VALUE> is the value. Default value at initialization is C<0>. On error an exception C<Error::Simple> is thrown.
 
-=item is_high_priority_login()
-
-Returns whether the login must be high priotity (is not available on development system used) or not.
-
 =item set_initially_open(VALUE)
 
 State that the communication link should be opened at the moment UNISPOOL is started. C<VALUE> is the value. On error an exception C<Error::Simple> is thrown.
 
-=item is_initially_open()
+=item set_name(VALUE)
 
-Returns whether the communication link should be opened at the moment UNISPOOL is started or not.
+This method is inherited from package C<HH::Unispool::Config::Entry>. Set the entry name. C<VALUE> is the value. C<VALUE> may not be C<undef>. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item VALUE must match regular expression:
+
+=over
+
+=item ^.+$
+
+=back
+
+=back
+
+=item set_number(VALUE)
+
+This method is inherited from package C<HH::Unispool::Config::Entry::Numbered>. Set the entry number. C<VALUE> is the value. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item VALUE must match regular expression:
+
+=over
+
+=item ^\d*$
+
+=back
+
+=back
 
 =item set_remote_node_name(VALUE)
 
@@ -268,10 +364,6 @@ Set the name of the system as it can be resolved by the network software. C<VALU
 
 =back
 
-=item get_remote_node_name()
-
-Returns the name of the system as it can be resolved by the network software.
-
 =item set_timeout(VALUE)
 
 Set the delay before closing the link after transfering the last request (in seconds) (is not available on development system used). C<VALUE> is the value. Default value at initialization is C<180>. On error an exception C<Error::Simple> is thrown.
@@ -288,10 +380,6 @@ Set the delay before closing the link after transfering the last request (in sec
 
 =back
 
-=item get_timeout()
-
-Returns the delay before closing the link after transfering the last request (in seconds) (is not available on development system used).
-
 =item set_upass(VALUE)
 
 Set the user paccword (is not available on development system used). C<VALUE> is the value. On error an exception C<Error::Simple> is thrown.
@@ -308,47 +396,9 @@ Set the user paccword (is not available on development system used). C<VALUE> is
 
 =back
 
-=item get_upass()
+=item write(FILE_HANDLE)
 
-Returns the user paccword (is not available on development system used).
-
-=back
-
-=head1 INHERITED METHODS FROM HH::Unispool::Config::Entry
-
-=over
-
-=item To access attribute named B<C<name>>:
-
-set_name(), get_name()
-
-=back
-
-=head1 INHERITED METHODS FROM HH::Unispool::Config::Entry::Numbered
-
-=over
-
-=item To access attribute named B<C<diff_number>>:
-
-set_diff_number(), is_diff_number()
-
-=item To access attribute named B<C<number>>:
-
-set_number(), get_number()
-
-=back
-
-=head1 INHERITED METHODS FROM HH::Unispool::Config::Entry::RemoteSystem
-
-=over
-
-=item To access attribute named B<C<description>>:
-
-set_description(), get_description()
-
-=item To access attribute named B<C<execution_priority>>:
-
-set_execution_priority(), get_execution_priority()
+This method is an implementation from package C<HH::Unispool::Config::Entry::RemoteSystem>. Writes the entry to the specified file handle. C<FILE_HANDLE> is an C<IO::Handle> reference. On error an exception C<Error::Simple> is thrown.
 
 =back
 
@@ -429,6 +479,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: February 2003
+Last update: September 2003
 
 =head1 AUTHOR
 
@@ -460,6 +511,53 @@ Boston, MA 02111-1307 USA
 
 =cut
 
+sub new_from_tokenizer {
+    my $class = shift;
+    my $tokenizer = shift;
+
+    # First token must be a HH::Unispool::Config::File::Token::Numbered::System::3
+    my $s = $tokenizer->get();
+    $s->isa('HH::Unispool::Config::File::Token::Numbered::System::3') || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::new_from_tokenizer, expected a first token from 'TOKENIZER' of class 'HH::Unispool::Config::File::Token::Numbered::System::3'.");
+
+    # Fill the initialization option hash
+    my %opt = ();
+    $opt{number} = $s->get_number() if ( $s->get_number() );
+    $opt{name} = $s->get_remote_system_name() if ( $s->get_remote_system_name() );
+    $opt{acct} = $s->get_acct() if ( $s->get_acct() );
+    $opt{apass} = $s->get_apass() if ( $s->get_apass() );
+    $opt{upass} = $s->get_upass() if ( $s->get_upass() );
+    $opt{timeout} = $s->get_timeout() if ( $s->get_timeout() );
+    $opt{high_priority_login} = $s->is_high_priority_login() if ( $s->is_high_priority_login() );
+    $opt{initially_open} = $s->is_initially_open() if ( $s->is_initially_open() );
+    $opt{execution_priority} = $s->get_execution_priority() if ( $s->get_execution_priority() );
+
+    # Allow an I and N token
+    my $i = undef;
+    my $n = undef;
+    while ( my $tok = $tokenizer->get() ) {
+        if ( ! $tok->isa('HH::Unispool::Config::File::Token::Numbered') || $tok->get_number() != $s->get_number() ) {
+            $tokenizer->unget();
+            last;
+        }
+        elsif ( $tok->isa('HH::Unispool::Config::File::Token::Numbered::System::Info') ) {
+            defined ($i) && throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::new_from_tokenizer, multiple tokens obtained from 'TOKENIZER' for entry $opt{name}/$opt{number} from class 'HH::Unispool::Config::File::Token::Numbered::System::Info'.");
+            $i = $tok;
+            $opt{description} = $i->get_description() if ( $i->get_description() );
+        }
+        elsif ( $tok->isa('HH::Unispool::Config::File::Token::Numbered::Network') ) {
+            defined ($n) && throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::new_from_tokenizer, multiple tokens obtained from 'TOKENIZER' for entry $opt{name}/$opt{number} from class 'HH::Unispool::Config::File::Token::Numbered::Network'.");
+            $n = $tok;
+            $opt{remote_node_name} = $n->get_remote_node_name() if ( $n->get_remote_node_name() );
+        }
+        else {
+            throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::new_from_tokenizer, expected tokens from 'TOKENIZER' for entry $opt{name}/$opt{number} from either class 'HH::Unispool::Config::File::Token::Numbered::System::Info' or 'HH::Unispool::Config::File::Token::Numbered::Network'.");
+        }
+    }
+
+    # Construct a new object and return it
+    return( HH::Unispool::Config::Entry::RemoteSystem::3->new(\%opt) );
+}
+
 sub _initialize {
     my $self = shift;
     my $opt = defined($_[0]) ? shift : {};
@@ -496,6 +594,49 @@ sub _initialize {
     return($self);
 }
 
+sub _value_is_allowed {
+    my $name = shift;
+
+    # Value is allowed if no ALLOW clauses exist for the named attribute
+    if ( ! exists( $ALLOW_ISA{$name} ) && ! exists( $ALLOW_REF{$name} ) && ! exists( $ALLOW_RX{$name} ) && ! exists( $ALLOW_VALUE{$name} ) ) {
+        return(1);
+    }
+
+    # At this point, all values in @_ must to be allowed
+    CHECK_VALUES:
+    foreach my $val (@_) {
+        # Check ALLOW_ISA
+        if ( ref($val) && exists( $ALLOW_ISA{$name} ) ) {
+            foreach my $class ( @{ $ALLOW_ISA{$name} } ) {
+                &UNIVERSAL::isa( $val, $class ) && next CHECK_VALUES;
+            }
+        }
+
+        # Check ALLOW_REF
+        if ( ref($val) && exists( $ALLOW_REF{$name} ) ) {
+            exists( $ALLOW_REF{$name}{ ref($val) } ) && next CHECK_VALUES;
+        }
+
+        # Check ALLOW_RX
+        if ( defined($val) && ! ref($val) && exists( $ALLOW_RX{$name} ) ) {
+            foreach my $rx ( @{ $ALLOW_RX{$name} } ) {
+                $val =~ /$rx/ && next CHECK_VALUES;
+            }
+        }
+
+        # Check ALLOW_VALUE
+        if ( ! ref($val) && exists( $ALLOW_VALUE{$name} ) ) {
+            exists( $ALLOW_VALUE{$name}{$val} ) && next CHECK_VALUES;
+        }
+
+        # We caught a not allowed value
+        return(0);
+    }
+
+    # OK, all values are allowed
+    return(1);
+}
+
 sub diff {
     my $from = shift;
     my $to = shift;
@@ -587,51 +728,133 @@ sub diff {
     return($diff);
 }
 
-sub new_from_tokenizer {
-    my $class = shift;
-    my $tokenizer = shift;
+sub get_acct {
+    my $self = shift;
 
-    # First token must be a HH::Unispool::Config::File::Token::Numbered::System::3
-    my $s = $tokenizer->get();
-    $s->isa('HH::Unispool::Config::File::Token::Numbered::System::3') || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::new_from_tokenizer, expected a first token from 'TOKENIZER' of class 'HH::Unispool::Config::File::Token::Numbered::System::3'.");
+    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{acct} );
+}
 
-    # Fill the initialization option hash
-    my %opt = ();
-    $opt{number} = $s->get_number() if ( $s->get_number() );
-    $opt{name} = $s->get_remote_system_name() if ( $s->get_remote_system_name() );
-    $opt{acct} = $s->get_acct() if ( $s->get_acct() );
-    $opt{apass} = $s->get_apass() if ( $s->get_apass() );
-    $opt{upass} = $s->get_upass() if ( $s->get_upass() );
-    $opt{timeout} = $s->get_timeout() if ( $s->get_timeout() );
-    $opt{high_priority_login} = $s->is_high_priority_login() if ( $s->is_high_priority_login() );
-    $opt{initially_open} = $s->is_initially_open() if ( $s->is_initially_open() );
-    $opt{execution_priority} = $s->get_execution_priority() if ( $s->get_execution_priority() );
+sub get_apass {
+    my $self = shift;
 
-    # Allow an I and N token
-    my $i = undef;
-    my $n = undef;
-    while ( my $tok = $tokenizer->get() ) {
-        if ( ! $tok->isa('HH::Unispool::Config::File::Token::Numbered') || $tok->get_number() != $s->get_number() ) {
-            $tokenizer->unget();
-            last;
-        }
-        elsif ( $tok->isa('HH::Unispool::Config::File::Token::Numbered::System::Info') ) {
-            defined ($i) && throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::new_from_tokenizer, multiple tokens obtained from 'TOKENIZER' for entry $opt{name}/$opt{number} from class 'HH::Unispool::Config::File::Token::Numbered::System::Info'.");
-            $i = $tok;
-            $opt{description} = $i->get_description() if ( $i->get_description() );
-        }
-        elsif ( $tok->isa('HH::Unispool::Config::File::Token::Numbered::Network') ) {
-            defined ($n) && throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::new_from_tokenizer, multiple tokens obtained from 'TOKENIZER' for entry $opt{name}/$opt{number} from class 'HH::Unispool::Config::File::Token::Numbered::Network'.");
-            $n = $tok;
-            $opt{remote_node_name} = $n->get_remote_node_name() if ( $n->get_remote_node_name() );
-        }
-        else {
-            throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::new_from_tokenizer, expected tokens from 'TOKENIZER' for entry $opt{name}/$opt{number} from either class 'HH::Unispool::Config::File::Token::Numbered::System::Info' or 'HH::Unispool::Config::File::Token::Numbered::Network'.");
-        }
+    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{apass} );
+}
+
+sub get_remote_node_name {
+    my $self = shift;
+
+    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{remote_node_name} );
+}
+
+sub get_timeout {
+    my $self = shift;
+
+    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{timeout} );
+}
+
+sub get_upass {
+    my $self = shift;
+
+    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{upass} );
+}
+
+sub is_high_priority_login {
+    my $self = shift;
+
+    if ( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{high_priority_login} ) {
+        return(1);
     }
+    else {
+        return(0);
+    }
+}
 
-    # Construct a new object and return it
-    return( HH::Unispool::Config::Entry::RemoteSystem::3->new(\%opt) );
+sub is_initially_open {
+    my $self = shift;
+
+    if ( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{initially_open} ) {
+        return(1);
+    }
+    else {
+        return(0);
+    }
+}
+
+sub set_acct {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'acct', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_acct, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{acct} = $val;
+}
+
+sub set_apass {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'apass', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_apass, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{apass} = $val;
+}
+
+sub set_high_priority_login {
+    my $self = shift;
+
+    if (shift) {
+        $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{high_priority_login} = 1;
+    }
+    else {
+        $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{high_priority_login} = 0;
+    }
+}
+
+sub set_initially_open {
+    my $self = shift;
+
+    if (shift) {
+        $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{initially_open} = 1;
+    }
+    else {
+        $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{initially_open} = 0;
+    }
+}
+
+sub set_remote_node_name {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'remote_node_name', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_remote_node_name, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{remote_node_name} = $val;
+}
+
+sub set_timeout {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'timeout', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_timeout, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{timeout} = $val;
+}
+
+sub set_upass {
+    my $self = shift;
+    my $val = shift;
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'upass', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_upass, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{upass} = $val;
 }
 
 sub write {
@@ -671,175 +894,3 @@ sub write {
     $fh->print( $n->write_string() );
 }
 
-sub set_acct {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'acct', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_acct, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{acct} = $val;
-}
-
-sub get_acct {
-    my $self = shift;
-
-    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{acct} );
-}
-
-sub set_apass {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'apass', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_apass, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{apass} = $val;
-}
-
-sub get_apass {
-    my $self = shift;
-
-    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{apass} );
-}
-
-sub set_high_priority_login {
-    my $self = shift;
-
-    if (shift) {
-        $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{high_priority_login} = 1;
-    }
-    else {
-        $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{high_priority_login} = 0;
-    }
-}
-
-sub is_high_priority_login {
-    my $self = shift;
-
-    if ( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{high_priority_login} ) {
-        return(1);
-    }
-    else {
-        return(0);
-    }
-}
-
-sub set_initially_open {
-    my $self = shift;
-
-    if (shift) {
-        $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{initially_open} = 1;
-    }
-    else {
-        $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{initially_open} = 0;
-    }
-}
-
-sub is_initially_open {
-    my $self = shift;
-
-    if ( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{initially_open} ) {
-        return(1);
-    }
-    else {
-        return(0);
-    }
-}
-
-sub set_remote_node_name {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'remote_node_name', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_remote_node_name, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{remote_node_name} = $val;
-}
-
-sub get_remote_node_name {
-    my $self = shift;
-
-    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{remote_node_name} );
-}
-
-sub set_timeout {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'timeout', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_timeout, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{timeout} = $val;
-}
-
-sub get_timeout {
-    my $self = shift;
-
-    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{timeout} );
-}
-
-sub set_upass {
-    my $self = shift;
-    my $val = shift;
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'upass', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::Entry::RemoteSystem::3::set_upass, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{upass} = $val;
-}
-
-sub get_upass {
-    my $self = shift;
-
-    return( $self->{HH_Unispool_Config_Entry_RemoteSystem_3}{upass} );
-}
-
-sub _value_is_allowed {
-    my $name = shift;
-
-    # Value is allowed if no ALLOW clauses exist for the named attribute
-    if ( ! exists( $ALLOW_ISA{$name} ) && ! exists( $ALLOW_REF{$name} ) && ! exists( $ALLOW_RX{$name} ) && ! exists( $ALLOW_VALUE{$name} ) ) {
-        return(1);
-    }
-
-    # At this point, all values in @_ must to be allowed
-    CHECK_VALUES:
-    foreach my $val (@_) {
-        # Check ALLOW_ISA
-        if ( ref($val) && exists( $ALLOW_ISA{$name} ) ) {
-            foreach my $class ( @{ $ALLOW_ISA{$name} } ) {
-                &UNIVERSAL::isa( $val, $class ) && next CHECK_VALUES;
-            }
-        }
-
-        # Check ALLOW_REF
-        if ( ref($val) && exists( $ALLOW_REF{$name} ) ) {
-            exists( $ALLOW_REF{$name}{ ref($val) } ) && next CHECK_VALUES;
-        }
-
-        # Check ALLOW_RX
-        if ( defined($val) && ! ref($val) && exists( $ALLOW_RX{$name} ) ) {
-            foreach my $rx ( @{ $ALLOW_RX{$name} } ) {
-                $val =~ /$rx/ && next CHECK_VALUES;
-            }
-        }
-
-        # Check ALLOW_VALUE
-        if ( ! ref($val) && exists( $ALLOW_VALUE{$name} ) ) {
-            exists( $ALLOW_VALUE{$name}{$val} ) && next CHECK_VALUES;
-        }
-
-        # We caught a not allowed value
-        return(0);
-    }
-
-    # OK, all values are allowed
-    return(1);
-}
-
