@@ -25,12 +25,8 @@ our %ALLOW_RX = (
 our %ALLOW_VALUE = (
 );
 
-# Used by _value_is_allowed
-our %DEFAULT_VALUE = (
-);
-
 # Package version
-our ($VERSION) = '$Revision: 0.2 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.3 $' =~ /\$Revision:\s+([^\s]+)/;
 
 1;
 
@@ -84,17 +80,73 @@ Passed to L<set_unget_buffer()>. Must be an C<ARRAY> reference.
 
 =over
 
+=item exists_got_buffer(ARRAY)
+
+Returns the count of items in C<ARRAY> that are in the I<got> buffer.
+
+=item exists_unget_buffer(ARRAY)
+
+Returns the count of items in C<ARRAY> that are in the I<unget> buffer.
+
 =item get()
 
 Either unget a C<HH::Unispool::Config::File::Token> from the B<unget buffer> and return it or read a line from the file, make a C<HH::Unispool::Config::File::Token> out of it and return it. On error a C<Error::Simple> exception is thrown.
 
+=item get_file()
+
+Returns the file handle to read from.
+
+=item get_got_buffer( [ INDEX_ARRAY ] )
+
+Returns an C<ARRAY> containing the I<got> buffer. C<INDEX_ARRAY> is an optional list of indexes which when specified causes only the indexed elements in the ordered list to be returned. If not specified, all elements are returned.
+
+=item get_unget_buffer( [ INDEX_ARRAY ] )
+
+Returns an C<ARRAY> containing the I<unget> buffer. C<INDEX_ARRAY> is an optional list of indexes which when specified causes only the indexed elements in the ordered list to be returned. If not specified, all elements are returned.
+
 =item input_line_number()
 
 Return the last read input line number.
 
-=item unget()
+=item pop_got_buffer()
 
-Unget the last token by moving it from the B<got buffer> to the B<unget buffer>. On error a C<Error::Simple> exception is thrown.
+Pop and return an element off the I<got> buffer. On error an exception C<Error::Simple> is thrown.
+
+=item pop_unget_buffer()
+
+Pop and return an element off the I<unget> buffer. On error an exception C<Error::Simple> is thrown.
+
+=item push_got_buffer(ARRAY)
+
+Push additional values on the I<got> buffer. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item The values in C<ARRAY> must be a (sub)class of:
+
+=over
+
+=item HH::Unispool::Config::File::Token
+
+=back
+
+=back
+
+=item push_unget_buffer(ARRAY)
+
+Push additional values on the I<unget> buffer. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item The values in C<ARRAY> must be a (sub)class of:
+
+=over
+
+=item HH::Unispool::Config::File::Token
+
+=back
+
+=back
 
 =item set_file(VALUE)
 
@@ -112,10 +164,6 @@ Set the file handle to read from. C<VALUE> is the value. C<VALUE> may not be C<u
 
 =back
 
-=item get_file()
-
-Returns the file handle to read from.
-
 =item set_got_buffer(ARRAY)
 
 Set the I<got> buffer absolutely. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
@@ -148,86 +196,6 @@ Set value in the I<got> buffer. C<INDEX> is the integer index which is greater t
 
 =back
 
-=item set_num_got_buffer( NUMBER, VALUE )
-
-Set value in the I<got> buffer. C<NUMBER> is the integer index which is greater than C<0>. C<VALUE> is the value.
-
-=over
-
-=item The values in C<ARRAY> must be a (sub)class of:
-
-=over
-
-=item HH::Unispool::Config::File::Token
-
-=back
-
-=back
-
-=item push_got_buffer(ARRAY)
-
-Push additional values on the I<got> buffer. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
-
-=over
-
-=item The values in C<ARRAY> must be a (sub)class of:
-
-=over
-
-=item HH::Unispool::Config::File::Token
-
-=back
-
-=back
-
-=item pop_got_buffer()
-
-Pop and return an element off the I<got> buffer. On error an exception C<Error::Simple> is thrown.
-
-=item shift_got_buffer()
-
-Shift and return an element off the I<got> buffer. On error an exception C<Error::Simple> is thrown.
-
-=item unshift_got_buffer(ARRAY)
-
-Unshift additional values on the I<got> buffer. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
-
-=over
-
-=item The values in C<ARRAY> must be a (sub)class of:
-
-=over
-
-=item HH::Unispool::Config::File::Token
-
-=back
-
-=back
-
-=item exists_got_buffer(ARRAY)
-
-Returns the count of items in C<ARRAY> that are in the I<got> buffer.
-
-=item get_got_buffer( [ INDEX_ARRAY ] )
-
-Returns an C<ARRAY> containing the I<got> buffer. C<INDEX_ARRAY> is an optional list of indexes which when specified causes only the indexed elements in the ordered list to be returned. If not specified, all elements are returned.
-
-=item set_unget_buffer(ARRAY)
-
-Set the I<unget> buffer absolutely. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
-
-=over
-
-=item The values in C<ARRAY> must be a (sub)class of:
-
-=over
-
-=item HH::Unispool::Config::File::Token
-
-=back
-
-=back
-
 =item set_idx_unget_buffer( INDEX, VALUE )
 
 Set value in the I<unget> buffer. C<INDEX> is the integer index which is greater than or equal to C<0>. C<VALUE> is the value.
@@ -244,6 +212,22 @@ Set value in the I<unget> buffer. C<INDEX> is the integer index which is greater
 
 =back
 
+=item set_num_got_buffer( NUMBER, VALUE )
+
+Set value in the I<got> buffer. C<NUMBER> is the integer index which is greater than C<0>. C<VALUE> is the value.
+
+=over
+
+=item The values in C<ARRAY> must be a (sub)class of:
+
+=over
+
+=item HH::Unispool::Config::File::Token
+
+=back
+
+=back
+
 =item set_num_unget_buffer( NUMBER, VALUE )
 
 Set value in the I<unget> buffer. C<NUMBER> is the integer index which is greater than C<0>. C<VALUE> is the value.
@@ -260,9 +244,9 @@ Set value in the I<unget> buffer. C<NUMBER> is the integer index which is greate
 
 =back
 
-=item push_unget_buffer(ARRAY)
+=item set_unget_buffer(ARRAY)
 
-Push additional values on the I<unget> buffer. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
+Set the I<unget> buffer absolutely. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
 
 =over
 
@@ -276,14 +260,34 @@ Push additional values on the I<unget> buffer. C<ARRAY> is the list value. On er
 
 =back
 
-=item pop_unget_buffer()
+=item shift_got_buffer()
 
-Pop and return an element off the I<unget> buffer. On error an exception C<Error::Simple> is thrown.
+Shift and return an element off the I<got> buffer. On error an exception C<Error::Simple> is thrown.
 
 =item shift_unget_buffer()
 
 Shift and return an element off the I<unget> buffer. On error an exception C<Error::Simple> is thrown.
 
+=item unget()
+
+Unget the last token by moving it from the B<got buffer> to the B<unget buffer>. On error a C<Error::Simple> exception is thrown.
+
+=item unshift_got_buffer(ARRAY)
+
+Unshift additional values on the I<got> buffer. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
+
+=over
+
+=item The values in C<ARRAY> must be a (sub)class of:
+
+=over
+
+=item HH::Unispool::Config::File::Token
+
+=back
+
+=back
+
 =item unshift_unget_buffer(ARRAY)
 
 Unshift additional values on the I<unget> buffer. C<ARRAY> is the list value. On error an exception C<Error::Simple> is thrown.
@@ -300,14 +304,6 @@ Unshift additional values on the I<unget> buffer. C<ARRAY> is the list value. On
 
 =back
 
-=item exists_unget_buffer(ARRAY)
-
-Returns the count of items in C<ARRAY> that are in the I<unget> buffer.
-
-=item get_unget_buffer( [ INDEX_ARRAY ] )
-
-Returns an C<ARRAY> containing the I<unget> buffer. C<INDEX_ARRAY> is an optional list of indexes which when specified causes only the indexed elements in the ordered list to be returned. If not specified, all elements are returned.
-
 =back
 
 =head1 SEE ALSO
@@ -387,6 +383,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: February 2003
+Last update: September 2003
 
 =head1 AUTHOR
 
@@ -416,7 +413,6 @@ along with the HH::Unispool::Config module hierarchy; if not, write to
 the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 Boston, MA 02111-1307 USA
 
-
 =cut
 
 sub new {
@@ -460,279 +456,6 @@ sub _initialize {
     return($self);
 }
 
-sub get {
-    my $self = shift;
-
-    # The token to get
-    my $tok;
-
-    # Shift an token from the unget buffer
-    if ( $tok = $self->pop_unget_buffer() ) {
-        $self->push_got_buffer($tok);
-    }
-
-    # Or try making a token from the file
-    else {
-        # Read a non empty line
-        my $line = undef;
-        while ( $line = $self->get_file()->getline() ) {
-            ( $line =~ /\S/ ) && last;
-        }
-
-        # Make a token out of the line
-        if ($line) {
-            use HH::Unispool::Config::File::Token::Factory;
-            my $fact = HH::Unispool::Config::File::Token::Factory->instance();
-            $tok = $fact->create_token( $line, $self->get_file()->input_line_number() );
-            $self->push_got_buffer($tok);
-        }
-    }
-
-    # Return the token
-    return($tok);
-}
-
-sub input_line_number {
-    my $self = shift;
-
-    my $prev = $self->pop_got_buffer();
-    if ( defined($prev) ) {
-        $self->push_got_buffer($prev);
-        return( $prev->get_input_line_number() );
-    }
-    else {
-        return(0);
-    }
-}
-
-sub unget {
-    my $self = shift;
-
-    my $tok = $self->pop_got_buffer();
-    defined($tok) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::unget, got buffer is empty.");
-    $self->push_unget_buffer($tok);
-}
-
-sub set_file {
-    my $self = shift;
-    my $val = shift;
-
-    # Value for 'file' is not allowed to be empty
-    defined($val) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_file, value may not be empty.");
-
-    # Check if isa/ref/rx/value is allowed
-    &_value_is_allowed( 'file', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_file, the specified value '$val' is not allowed.");
-
-    # Assignment
-    $self->{HH_Unispool_Config_File_Tokenizer}{file} = $val;
-}
-
-sub get_file {
-    my $self = shift;
-
-    return( $self->{HH_Unispool_Config_File_Tokenizer}{file} );
-}
-
-sub set_got_buffer {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'got_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_got_buffer, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Set the list
-    @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } = @_;
-}
-
-sub set_idx_got_buffer {
-    my $self = shift;
-    my $idx = shift;
-    my $val = shift;
-
-    # Check if index is a positive integer or zero
-    ( $idx == int($idx) ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_got_buffer, the specified index '$idx' is not an integer.");
-    ( $idx >= 0 ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_got_buffer, the specified index '$idx' is not a positive integer or zero.");
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'got_buffer', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_got_buffer, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Set the value in the list
-    $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer}[$idx] = $val;
-}
-
-sub set_num_got_buffer {
-    my $self = shift;
-    my $num = shift;
-
-    # Check if index is an integer
-    ( $num == int($num) ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_num_got_buffer, the specified number '$num' is not an integer.");
-
-    # Call set_idx_got_buffer
-    $self->set_idx_got_buffer( $num - 1,  );
-}
-
-sub push_got_buffer {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'got_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::push_got_buffer, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Push the list
-    push( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} }, @_ );
-}
-
-sub pop_got_buffer {
-    my $self = shift;
-
-    # Pop an element from the list
-    return( pop( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } ) );
-}
-
-sub shift_got_buffer {
-    my $self = shift;
-
-    # Shift an element from the list
-    return( shift( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } ) );
-}
-
-sub unshift_got_buffer {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'got_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::unshift_got_buffer, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Unshift the list
-    unshift( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} }, @_ );
-}
-
-sub exists_got_buffer {
-    my $self = shift;
-
-    # Count occurences
-    my $count = 0;
-    foreach my $val1 (@_) {
-        foreach my $val2 ( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } ) {
-            ( $val1 eq $val2 ) && $count ++;
-        }
-    }
-    return($count);
-}
-
-sub get_got_buffer {
-    my $self = shift;
-
-    if ( scalar(@_) ) {
-        my @ret = ();
-        foreach my $i (@_) {
-            push( @ret, $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer}[ int($i) ] );
-        }
-        return(@ret);
-    }
-    else {
-        # Return the full list
-        return( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } );
-    }
-}
-
-sub set_unget_buffer {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'unget_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_unget_buffer, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Set the list
-    @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } = @_;
-}
-
-sub set_idx_unget_buffer {
-    my $self = shift;
-    my $idx = shift;
-    my $val = shift;
-
-    # Check if index is a positive integer or zero
-    ( $idx == int($idx) ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_unget_buffer, the specified index '$idx' is not an integer.");
-    ( $idx >= 0 ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_unget_buffer, the specified index '$idx' is not a positive integer or zero.");
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'unget_buffer', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_unget_buffer, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Set the value in the list
-    $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer}[$idx] = $val;
-}
-
-sub set_num_unget_buffer {
-    my $self = shift;
-    my $num = shift;
-
-    # Check if index is an integer
-    ( $num == int($num) ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_num_unget_buffer, the specified number '$num' is not an integer.");
-
-    # Call set_idx_unget_buffer
-    $self->set_idx_unget_buffer( $num - 1,  );
-}
-
-sub push_unget_buffer {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'unget_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::push_unget_buffer, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Push the list
-    push( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} }, @_ );
-}
-
-sub pop_unget_buffer {
-    my $self = shift;
-
-    # Pop an element from the list
-    return( pop( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } ) );
-}
-
-sub shift_unget_buffer {
-    my $self = shift;
-
-    # Shift an element from the list
-    return( shift( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } ) );
-}
-
-sub unshift_unget_buffer {
-    my $self = shift;
-
-    # Check if isas/refs/rxs/values are allowed
-    &_value_is_allowed( 'unget_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::unshift_unget_buffer, one or more specified value(s) '@_' is/are not allowed.");
-
-    # Unshift the list
-    unshift( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} }, @_ );
-}
-
-sub exists_unget_buffer {
-    my $self = shift;
-
-    # Count occurences
-    my $count = 0;
-    foreach my $val1 (@_) {
-        foreach my $val2 ( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } ) {
-            ( $val1 eq $val2 ) && $count ++;
-        }
-    }
-    return($count);
-}
-
-sub get_unget_buffer {
-    my $self = shift;
-
-    if ( scalar(@_) ) {
-        my @ret = ();
-        foreach my $i (@_) {
-            push( @ret, $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer}[ int($i) ] );
-        }
-        return(@ret);
-    }
-    else {
-        # Return the full list
-        return( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } );
-    }
-}
-
 sub _value_is_allowed {
     my $name = shift;
 
@@ -776,3 +499,276 @@ sub _value_is_allowed {
     return(1);
 }
 
+sub exists_got_buffer {
+    my $self = shift;
+
+    # Count occurrences
+    my $count = 0;
+    foreach my $val1 (@_) {
+        foreach my $val2 ( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } ) {
+            ( $val1 eq $val2 ) && $count ++;
+        }
+    }
+    return($count);
+}
+
+sub exists_unget_buffer {
+    my $self = shift;
+
+    # Count occurrences
+    my $count = 0;
+    foreach my $val1 (@_) {
+        foreach my $val2 ( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } ) {
+            ( $val1 eq $val2 ) && $count ++;
+        }
+    }
+    return($count);
+}
+
+sub get {
+    my $self = shift;
+
+    # The token to get
+    my $tok;
+
+    # Shift an token from the unget buffer
+    if ( $tok = $self->pop_unget_buffer() ) {
+        $self->push_got_buffer($tok);
+    }
+
+    # Or try making a token from the file
+    else {
+        # Read a non empty line
+        my $line = undef;
+        while ( $line = $self->get_file()->getline() ) {
+            ( $line =~ /\S/ ) && last;
+        }
+
+        # Make a token out of the line
+        if ($line) {
+            use HH::Unispool::Config::File::Token::Factory;
+            my $fact = HH::Unispool::Config::File::Token::Factory->instance();
+            $tok = $fact->create_token( $line, $self->get_file()->input_line_number() );
+            $self->push_got_buffer($tok);
+        }
+    }
+
+    # Return the token
+    return($tok);
+}
+
+sub get_file {
+    my $self = shift;
+
+    return( $self->{HH_Unispool_Config_File_Tokenizer}{file} );
+}
+
+sub get_got_buffer {
+    my $self = shift;
+
+    if ( scalar(@_) ) {
+        my @ret = ();
+        foreach my $i (@_) {
+            push( @ret, $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer}[ int($i) ] );
+        }
+        return(@ret);
+    }
+    else {
+        # Return the full list
+        return( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } );
+    }
+}
+
+sub get_unget_buffer {
+    my $self = shift;
+
+    if ( scalar(@_) ) {
+        my @ret = ();
+        foreach my $i (@_) {
+            push( @ret, $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer}[ int($i) ] );
+        }
+        return(@ret);
+    }
+    else {
+        # Return the full list
+        return( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } );
+    }
+}
+
+sub input_line_number {
+    my $self = shift;
+
+    my $prev = $self->pop_got_buffer();
+    if ( defined($prev) ) {
+        $self->push_got_buffer($prev);
+        return( $prev->get_input_line_number() );
+    }
+    else {
+        return(0);
+    }
+}
+
+sub pop_got_buffer {
+    my $self = shift;
+
+    # Pop an element from the list
+    return( pop( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } ) );
+}
+
+sub pop_unget_buffer {
+    my $self = shift;
+
+    # Pop an element from the list
+    return( pop( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } ) );
+}
+
+sub push_got_buffer {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'got_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::push_got_buffer, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Push the list
+    push( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} }, @_ );
+}
+
+sub push_unget_buffer {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'unget_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::push_unget_buffer, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Push the list
+    push( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} }, @_ );
+}
+
+sub set_file {
+    my $self = shift;
+    my $val = shift;
+
+    # Value for 'file' is not allowed to be empty
+    defined($val) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_file, value may not be empty.");
+
+    # Check if isa/ref/rx/value is allowed
+    &_value_is_allowed( 'file', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_file, the specified value '$val' is not allowed.");
+
+    # Assignment
+    $self->{HH_Unispool_Config_File_Tokenizer}{file} = $val;
+}
+
+sub set_got_buffer {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'got_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_got_buffer, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Set the list
+    @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } = @_;
+}
+
+sub set_idx_got_buffer {
+    my $self = shift;
+    my $idx = shift;
+    my $val = shift;
+
+    # Check if index is a positive integer or zero
+    ( $idx == int($idx) ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_got_buffer, the specified index '$idx' is not an integer.");
+    ( $idx >= 0 ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_got_buffer, the specified index '$idx' is not a positive integer or zero.");
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'got_buffer', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_got_buffer, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Set the value in the list
+    $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer}[$idx] = $val;
+}
+
+sub set_idx_unget_buffer {
+    my $self = shift;
+    my $idx = shift;
+    my $val = shift;
+
+    # Check if index is a positive integer or zero
+    ( $idx == int($idx) ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_unget_buffer, the specified index '$idx' is not an integer.");
+    ( $idx >= 0 ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_unget_buffer, the specified index '$idx' is not a positive integer or zero.");
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'unget_buffer', $val ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_idx_unget_buffer, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Set the value in the list
+    $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer}[$idx] = $val;
+}
+
+sub set_num_got_buffer {
+    my $self = shift;
+    my $num = shift;
+
+    # Check if index is an integer
+    ( $num == int($num) ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_num_got_buffer, the specified number '$num' is not an integer.");
+
+    # Call set_idx_got_buffer
+    $self->set_idx_got_buffer( $num - 1, @_ );
+}
+
+sub set_num_unget_buffer {
+    my $self = shift;
+    my $num = shift;
+
+    # Check if index is an integer
+    ( $num == int($num) ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_num_unget_buffer, the specified number '$num' is not an integer.");
+
+    # Call set_idx_unget_buffer
+    $self->set_idx_unget_buffer( $num - 1, @_ );
+}
+
+sub set_unget_buffer {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'unget_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::set_unget_buffer, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Set the list
+    @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } = @_;
+}
+
+sub shift_got_buffer {
+    my $self = shift;
+
+    # Shift an element from the list
+    return( shift( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} } ) );
+}
+
+sub shift_unget_buffer {
+    my $self = shift;
+
+    # Shift an element from the list
+    return( shift( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} } ) );
+}
+
+sub unget {
+    my $self = shift;
+
+    my $tok = $self->pop_got_buffer();
+    defined($tok) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::unget, got buffer is empty.");
+    $self->push_unget_buffer($tok);
+}
+
+sub unshift_got_buffer {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'got_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::unshift_got_buffer, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Unshift the list
+    unshift( @{ $self->{HH_Unispool_Config_File_Tokenizer}{got_buffer} }, @_ );
+}
+
+sub unshift_unget_buffer {
+    my $self = shift;
+
+    # Check if isas/refs/rxs/values are allowed
+    &_value_is_allowed( 'unget_buffer', @_ ) || throw Error::Simple("ERROR: HH::Unispool::Config::File::Tokenizer::unshift_unget_buffer, one or more specified value(s) '@_' is/are not allowed.");
+
+    # Unshift the list
+    unshift( @{ $self->{HH_Unispool_Config_File_Tokenizer}{unget_buffer} }, @_ );
+}
+
